@@ -17,7 +17,6 @@ from logilab.mtconverter import guess_mimetype_and_encoding
 from yams import ValidationError
 
 from cubicweb import Binary, QueryError, typed_eid
-from cubicweb.server.session import security_enabled
 from cubes.vcsfile import queries
 
 _VCSTYPES = {'subversion': LazyObject('cubes.vcsfile.reposvn', 'SVNRepository'),
@@ -49,7 +48,7 @@ def repository_handler(repoent):
     # deactivate read security first, potentially needed to get access to
     # path/local_cache
     session = repoent._cw
-    with security_enabled(session, read=False):
+    with session.security_enabled(read=False):
         try:
             repohdlr = _REPOHDLRS[repoent.eid]
             repohdlr.encoding = repoent.encoding # in case it changed
