@@ -67,7 +67,7 @@ def clone_to_local_cache(vcsrepo):
     handler = bridge.repository_handler(vcsrepo)
     url = vcsrepo.source_url
     try:
-        handler.pull_or_clone_cache(url)
+        handler.pull_or_clone_cache(url, vcsrepo._cw.vreg.config)
     except Exception:
         handler.exception('while trying to clone repo %s', url)
         msg = vcsrepo._cw._('can not clone the repo from %s, '
@@ -456,7 +456,7 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
       * None for all vcs repos
       * a list of integers for specific vcs repos
     '''
-    with repo.internal_session() as session:
+    with repo.internal_session(safe=True) as session:
         config = session.vreg.config
         rql = ('Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
                'NOT (R local_cache NULL AND R path NULL),'
@@ -490,7 +490,8 @@ def _refresh_repos(repo, eids=None, bridge=bridge):
             if (config['repository-import'] or vcsrepo.import_revision_content) \
                    and vcsrepo.local_cache is not None:
                 try:
-                    repohdlr.pull_or_clone_cache(vcsrepo.source_url)
+                    repohdlr.pull_or_clone_cache(vcsrepo.source_url,
+                                                 vcsrepo._cw.vreg.config)
                 except bridge.VCSException, ex:
                     repohdlr.error(str(ex))
                 except Exception:
@@ -522,7 +523,7 @@ class VCSRepoNotifHook(hook.Hook):
         def callback(msg):
             self.debug('received notification: %s', ' '.join(msg))
             msg = msg[-1]
-            with self.repo.internal_session() as session:
+            with self.repo.internal_session(safe=True) as session:
                 for suffix in ('', '/'):
                     rset = session.execute('Any R WHERE R source_url U, '
                                             'R source_url LIKE %(u)s',
