@@ -1,7 +1,7 @@
 """entity types used to represent a version control system (vcs) content
 
 :organization: Logilab
-:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -128,9 +128,9 @@ class VersionContent(DeletedVersionContent):
     """actual content of a versioned file, for a given revision"""
     data = Bytes(description=_("file's data"), required=True,
                  __permissions__=RO_ATTRPERMS)
-    data_format = String(required=True, meta=True, maxsize=128,
+    data_format = String(required=True, maxsize=128,
                          description=_('MIME type of the file.'))
-    data_encoding = String(meta=True, maxsize=32,
+    data_encoding = String(maxsize=32,
                            description=_('encoding of the file when it applies (e.g. text).'))
 
 
