@@ -1,6 +1,7 @@
 from mercurial import cmdutil
 from mercurial import patch
 from mercurial import ui as uimod
+from mercurial.error import RepoError
 
 from cubicweb import Binary
 from cubicweb.server import Service
@@ -25,7 +26,10 @@ class RevisionExportService(Service):
                                        'unified': 5,
                                        })
         hdrepo = bridge.repository_handler(repo)
-        hgrepo = hdrepo.hgrepo()
+        try:
+            hgrepo = hdrepo.hgrepo()
+        except RepoError:
+            return None
         if nodeid not in hgrepo:
             # local cache miss
             return None
