@@ -1,7 +1,7 @@
 """app objects for vcsfile web interface
 
 :organization: Logilab
-:copyright: 2007-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
@@ -9,7 +9,7 @@ __docformat__ = "restructuredtext en"
 
 
 from cubicweb import typed_eid
-from cubicweb.selectors import match_form_params
+from cubicweb.predicates import match_form_params
 from cubicweb.web import Redirect, RequestError
 from cubicweb.web.controller import Controller
 
