@@ -92,8 +92,7 @@ class VCRevisionAllFilesAction(VCAction):
     def url(self):
         entity = self.cw_rset.get_entity(0, 0)
         repoeid = entity.file.repository.eid
-        rql, args = rql_revision_content(repoeid, entity.rev.revision,
-                                         entity.rev.branch)
+        rql, args = rql_revision_content(repoeid, entity.rev.revision)
         return self._cw.build_url('view', rql=rql % args, vid='list')
 
 
