@@ -16,6 +16,7 @@ from logilab.common.decorators import cached
 from cubicweb.predicates import (match_form_params, match_kwargs,
                                  is_instance, specified_etype_implements,
                                  match_edited_type)
+from cubicweb import Forbidden
 from cubicweb.view import EntityView
 from cubicweb.web import (Redirect, RequestError, controller, uicfg, form,
                           formfields as ff, formwidgets as fw)
@@ -207,11 +208,14 @@ class VFUploadController(controller.Controller):
         raise Redirect(goto)
 
     def upload_revision(self, vf, formparams):
-        # [-1] to discard file name and mime type
-        stream = formparams['file'][-1]
-        vf.vcs_upload_revision(stream, branch=formparams['branch'],
-                               msg=formparams['msg'])
-        return vf.eid
+        try:
+            # [-1] to discard file name and mime type
+            stream = formparams['file'][-1]
+            vf.vcs_upload_revision(stream, branch=formparams['branch'],
+                                   msg=formparams['msg'])
+            return vf.eid
+        except KeyError:
+            raise Forbidden('Invalid content')
 
 
 class VcsRmForm(form.FormViewMixIn, EntityView):
