@@ -212,7 +212,8 @@ class VCRevisionView(EntityView):
 
     def cell_call(self, row, col):
         vc = self.cw_rset.get_entity(row, col)
-        self.w(u'<a href="%s">' % vc.absolute_url())
+        self.w(u'<a href="%s" title="%s">' % (vc.absolute_url(),
+                                              xml_escape(vc.rev.description)))
         vc.rev.view('shorttext', w=self.w)
         self.w(u'</a>')
 
